/* main.c - This module opens up a graphics display,  and sends all the
 * flics in the command line over to routines in readflic.c to play back.
 *
 * Copyright (c) 1992 Jim Kent.  This file may be freely used, modified,
 * copied and distributed.  This file was first published as part of
 * an article for Dr. Dobb's Journal March 1993 issue.
 */
#include "types.h"
#include "pcclone.h"
#include "flic.h"
#include "readflic.h"

static char about[] =
"PHILFLIC - a program that plays back .FLI and .FLC files.  Its based on\n"
"code by Jim Kent, the author of Animator. \n"

static void center_flic(Flic *flic, Screen *s)
	/* Set flic.xoff and flic.yoff so flic plays centered rather
	 * than in upper left corner of display. */
{
	flic->xoff = (screen_width(s) - (signed)flic->head.width)/2;
	flic->yoff = (screen_height(s) - (signed)flic->head.height)/2;
}

int main(int argc, char *argv[])
	/* Check command line.  If empty print usage message.  Otherwise
	 * open up machine for animation (get screen, clock & keyboard)
	 * and play back flics.
	 */
{
int myReturn;
ErrCode err;
char *title = argv[1];
Flic flic;
int i;
Machine machine;

	/* Check command line for any flics.  If none then print usage
	 * instructions and exit. */
if (argc < 2)
	{
	puts(about);
	return(2);
	}
if ((err = machine_open(&machine)) >= Success)
	{
		for (i=1; i<argc; ++i)
			{
			title = argv[i];
			if ((err = flic_open(&flic, title)) >= Success)
				{
				center_flic(&flic, &machine.screen);
				err = flic_play_once(&flic, &machine);
				flic_close(&flic);
				}
			if (err < Success)
				break;
			}
	machine_close(&machine);
	}
	/* Report errors back in text mode. */
	myReturn=0; /* cool */
	if (err < Success && err != ErrCancel)
		myReturn=2; /* problem */
	if ( err == ErrCancel)
		myReturn=1; /* user interrupt */
	return(myReturn);
}
